@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Tue Dec  7 15:27:32 PST 2010
+ * Generated Mon Dec 13 00:09:49 PST 2010
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -203,7 +203,7 @@ LOCAL void
 ag_scribble_free(void);
 
 LOCAL char*
-ag_scribble(size_t size);
+ag_scribble(ssize_t size);
 
 /*
  *  Extracted from tpLoad.c
