@@ -2,11 +2,10 @@
 ##  -*- Mode: shell-script -*-
 ## mklibsrc.sh --   make the libopts tear-off library source tarball
 ##
-## Time-stamp:      "2007-07-04 13:02:38 bkorb"
-##              by: bkorb
+## Time-stamp:      "2010-07-17 09:45:10 bkorb"
 ##
 ##  This file is part of AutoGen.
-##  AutoGen copyright (c) 1992-2007 Bruce Korb - all rights reserved
+##  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
 ##
 ##  AutoGen is free software: you can redistribute it and/or modify it
 ##  under the terms of the GNU General Public License as published by the
@@ -20,10 +19,6 @@
 ##
 ##  You should have received a copy of the GNU General Public License along
 ##  with this program.  If not, see <http://www.gnu.org/licenses/>.
-## ---------------------------------------------------------------------
-## $Id: mklibsrc.sh,v 4.19 2007/07/04 20:51:20 bkorb Exp $
-## ---------------------------------------------------------------------
-## Code:
 
 set -e -x
 
@@ -50,6 +45,9 @@ files=`fgrep '#include' libopts.c | \
        sed -e 's,"$,,;s,#.*",,' \
            -e '/^compat\/compat\.h$/d' `
 
+egrep "#define HAVE_PARSE_DURATION" ${top_builddir}/config.h >/dev/null || \
+  files="${files} parse-duration.c parse-duration.h"
+
 for f in libopts.c ${files}
 do
   if test -f ${f}
@@ -63,7 +61,6 @@ cp -f ${top_srcdir}/pkg/libopts/COPYING.* ${tagd}/.
 cd ${top_srcdir}/compat
 cp windows-config.h compat.h pathfind.c snprintf.c strdup.c strchr.c \
    ${tagd}/compat/.
-
 #
 #  END WORK IN SOURCE DIRECTORY
 #
@@ -96,7 +93,7 @@ cat >&3 <<- EOMakefile
 	EXTRA_DIST              = \\
 	EOMakefile
 
-find * -type f \
+find $(ls -A) -type f \
   | egrep -v '^(libopts\.c|Makefile\.am)$' \
   | ${CLexe} -I4 --spread=1 --line-sep="  \\" >&3
 exec 3>&-
@@ -117,7 +114,7 @@ tar cvf - ${tag} | $gz > ${top_builddir}/autoopts/${tag}.${sfx}
 rm -rf ${tag}
 
 ## Local Variables:
-## Mode: shell-script
+## mode: shell-script
 ## indent-tabs-mode: nil
 ## sh-indentation: 2
 ## sh-basic-offset: 2
